pub struct EncodedString { /* private fields */ }Expand description
String representation of serialized data.
This type represents data that has been serialized into a string format, along with information about which serialization format was used.
Implementations
Sourceimpl EncodedString
impl EncodedString
Sourcepub const fn new(encoding: Encoding, string: String) -> Self
pub const fn new(encoding: Encoding, string: String) -> Self
Creates a new SerialString instance.
Arguments
serialise_type- The format used to serialize the datastring- The serialized string representation
Sourcepub const fn get_encoding(&self) -> Encoding
pub const fn get_encoding(&self) -> Encoding
Sourcepub const fn get_string(&self) -> &String
pub const fn get_string(&self) -> &String